The following package contains a distribution parent class, gaussian distribution, and binomial distribution classes. 
Each class can calculate mean, and standard deviation from a data set.
The binomial class delivers mean, standard deviation, n and p